pub struct AppWidget { /* fields omitted */ }
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Convert self to an optional value of a Properties struct.
Convert self to a value of a Properties struct.
Convert self to a value of a Properties struct.
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<T> Any for T where
T: Any,